# Changelog

## 1.5.0 (2024-12-26)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/evrimai/python-client/compare/v1.4.0...v1.5.0)

### Features

* **api:** update via SDK Studio ([#17](https://github.com/evrimai/python-client/issues/17)) ([6d9929d](https://github.com/evrimai/python-client/commit/6d9929d302938fd218313ddeb255fa5bae071488))

## 1.4.0 (2024-12-26)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/evrimai/python-client/compare/v1.3.0...v1.4.0)

### Features

* **api:** update via SDK Studio ([#14](https://github.com/evrimai/python-client/issues/14)) ([1733653](https://github.com/evrimai/python-client/commit/17336532dc3f942af8f428889f42c02a0f86183f))

## 1.3.0 (2024-12-26)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/evrimai/python-client/compare/v1.2.0...v1.3.0)

### Features

* **api:** update via SDK Studio ([#11](https://github.com/evrimai/python-client/issues/11)) ([db885e8](https://github.com/evrimai/python-client/commit/db885e815107118ca29aa51913b87a11d6da28ba))

## 1.2.0 (2024-12-26)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/evrimai/python-client/compare/v1.1.0...v1.2.0)

### Features

* **api:** update via SDK Studio ([#8](https://github.com/evrimai/python-client/issues/8)) ([849dfe9](https://github.com/evrimai/python-client/commit/849dfe93bfa69955739dcc856190818a23c26c98))

## 1.1.0 (2024-12-24)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/evrimai/python-client/compare/v1.0.0...v1.1.0)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/evrimai/python-client/issues/5)) ([2a790b2](https://github.com/evrimai/python-client/commit/2a790b24ef4069baa1a9bf5821e59217f13dbadd))

## 1.0.0 (2024-12-24)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/evrimai/python-client/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* go live ([#1](https://github.com/evrimai/python-client/issues/1)) ([ae010a1](https://github.com/evrimai/python-client/commit/ae010a160d0c1b0d2a4f8c436cc87b2219bad52f))
* update SDK settings ([#3](https://github.com/evrimai/python-client/issues/3)) ([70e424b](https://github.com/evrimai/python-client/commit/70e424b5e76aceff0e5536a894768870ea14977a))
